autowisp.database.data_model.steps_and_parameters module — AutoWISP documentation

# autowisp.database.data_model.steps_and_parameters module

## Class Inheritance Diagram

Define the step type table for the pipeline

class autowisp.database.data_model.steps_and_parameters.Parameter(**kwargs)

  Bases: `DataModelBase`

  Table describing the configuration parameters needed by the pipeline.

  description

    Description of what the step does.

  id

    A unique identifier for each row.

  name

    The name of the step within the pipeline.

  steps: Mapped[List[Step]]
  timestamp

    When record was last changed

class autowisp.database.data_model.steps_and_parameters.Step(**kwargs)

  Bases: `DataModelBase`

  The table describing the processing steps constituting the pipeline

  description

    Description of what the step does.

  id

    A unique identifier for each row.

  name

    The name of the step within the pipeline.

  parameters: Mapped[List[Parameter]]
  prerequisites: Mapped[List[StepDependencies]]
  timestamp

    When record was last changed